@@ -3,10 +3,16 @@
 from __future__ import absolute_import, unicode_literals
 
 from abc import ABCMeta, abstractmethod, abstractproperty
-from collections import Callable
 
 from celery.five import with_metaclass
 
+try:
+    from collections.abc import Callable
+except ImportError:
+    # TODO: Remove this when we drop Python 2.7 support
+    from collections import Callable
+
+
 __all__ = ('CallableTask', 'CallableSignature')
 
 
